@@ -5,11 +5,11 @@ module GLib
   class Error
     GIR_FFI_DOMAIN = GLib.quark_from_string('gir_ffi')
 
-    def self.from_exception ex
+    def self.from_exception(ex)
       new_literal GIR_FFI_DOMAIN, 0, ex.message
     end
 
-    def self.from it
+    def self.from(it)
       from_exception it
     end
   end
