@@ -3,7 +3,7 @@ module GirFFI
     # Builder that generates code to convert values from Ruby to C. Used by
     # argument builders.
     class RubyToCConvertor
-      def initialize type_info, argument_name
+      def initialize(type_info, argument_name)
         @type_info = type_info
         @argument_name = argument_name
       end
@@ -13,7 +13,7 @@ module GirFFI
         "#{@type_info.argument_class_name}.from(#{args})"
       end
 
-      def conversion_arguments name
+      def conversion_arguments(name)
         @type_info.extra_conversion_arguments.map(&:inspect).push(name).join(', ')
       end
     end
