@@ -6,11 +6,6 @@ module GirFFI
   module RegisteredTypeBase
     include TypeBase
 
-    # @deprecated Use #gtype. Will be removed in 0.8.0.
-    def get_gtype
-      gtype
-    end
-
     def gtype
       self::G_TYPE
     end
